/**
Program balances the records so that all parameter configurations have the 
same number of records.

Author: Marius Mikucionis <marius@cs.aau.dk>

Developed as part of results for the following publication:

Alexandre David, Kim Guldstrand Larsen, Marius Mikučionis, Axel Legay and 
Dehui Du: Optmizing Control Strategy using Statistical Model Checking. 
To appear in the proceedings of NASA Formal Methods 2013.
 */

#include <iostream>
#include <list>
#include <map>
#include <cstdlib>
#include <cmath>

using namespace std;


struct config_t {
  int ton, tget;
};

bool operator<(const config_t& c1, const config_t& c2)
{
  if (c1.tget < c2.tget) return true;
  else if (c1.tget == c2.tget) return (c1.ton < c2.ton);
  return false;
}

std::istream& operator>>(std::istream& os, config_t& c) 
{
  return os >> c.ton >> c.tget;
}

std::ostream& operator<<(std::ostream& os, const config_t& c) 
{
  return os << c.ton << " " << c.tget;
}

struct values_t {
  double discomfort, energy;
};

std::istream& operator>>(std::istream& os, values_t& v) 
{
  return os >> v.discomfort >> v.energy;
}


std::ostream& operator<<(std::ostream& os, const values_t& v) 
{
  return os << v.discomfort << " " << v.energy;
}

typedef map<config_t,list<values_t> > tuples_t;

int main(const int argc, const char* args[]) 
{
  config_t cc;
  values_t cv;
  tuples_t data;
  int filled = 0;

  while (cin) {
    cin >> cc >> cv;
    list<values_t> &vl = data[cc];
    if (vl.empty()) ++filled;
    vl.push_back(cv);
    if (filled == 49) { // filled one level
      filled = 0; // output it:
      for (tuples_t::iterator i=data.begin(),e=data.end(); i!=e; i++) {
	list<values_t> &tmp = i->second;	
	cout << i->first << " " << tmp.front() << endl;
	tmp.pop_front(); // discard
	if (!tmp.empty()) ++filled; // check if the next level is ready
      }
    }
  }
  // discard the rest
}
