source("meansF.R")

system('cat means.dat | ./dominators-means > means-pareto.dat')
system('gnuplot meansF.plot')

### Visualization via levelplots:
require(lattice)
min_pareto<-read.table("pareto.dat", col.names=c("Ton", "Tget", "discomfort", "energy"))
mean_pareto<-read.table("means-pareto.dat", col.names=c("Ton", "Tget", "discomfort", "energy", "discomfort_err", "energy_err"))
postscript(file="discomfort-levels.eps", horizontal=F, paper="special", width=3.5, height=2.5)
levelplot(discomfort ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=0.5, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=1.5, col="blue")
   })
dev.off()

postscript(file="energy-levels.eps", horizontal=F, paper="special", width=3.5, height=2.5)
levelplot(energy ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=0.8),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=1.5, col="red")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=0.5, col="blue")
   })
dev.off()

## BIG LEVEL PLOTS:

postscript(file="discomfort-levels-b.eps", horizontal=F, paper="special", width=4.5, height=4)
levelplot(discomfort ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=1),
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=2.7, col="white")
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=3, col="white")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget,  cex=1.5, col="blue")
   })
dev.off()

postscript(file="energy-levels-b.eps", horizontal=F, paper="special", width=4.3, height=4)
levelplot(energy ~ Ton*Tget, data=meandata, col.regions=gray(20:100/100), contour=TRUE,
   colorkey=list(width=1), ylab="",
   panel = function(...){ 
      panel.levelplot(...) 
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=2.7, col="white")
      panel.xyplot(mean_pareto$Ton, mean_pareto$Tget, cex=3, col="white")
      panel.xyplot(min_pareto$Ton, min_pareto$Tget, cex=1.5, col="blue")
   })
dev.off()


### Analyze means in 3D:
library(scatterplot3d)
postscript(file="discomfort-fit.eps", horizontal=F, paper="special", width=6, height=4)
# plot means:
s3d <- with(meandata, scatterplot3d(Ton, Tget, discomfort, highlight.3d=TRUE, pch=20))
# plot linear model plane:
lmodel <- with(meandata, lm(discomfort ~ Ton + Tget))
s3d$plane3d(lmodel, lty="dotted")
# plot the deviation columns from linear model:
orig <- with(meandata, s3d$xyz.convert(Ton, Tget, discomfort))
plane <- with(meandata, s3d$xyz.convert(Ton, Tget, fitted(lmodel)))
i.negpos <- 1+(resid(lmodel)>0)
segments(orig$x, orig$y, plane$x, plane$y, col=c("blue","red")[i.negpos],lty=(2:1)[i.negpos])
dev.off();

postscript(file="energy-fit.eps", horizontal=F, paper="special", width=6, height=4)
# plot means:
s3d <- with(meandata, scatterplot3d(Ton, Tget, energy, highlight.3d=TRUE, pch=20))
# plot linear model plane:
lmodel <- with(meandata, lm(energy ~ Ton + Tget))
s3d$plane3d(lmodel, lty="dotted")
# plot the deviation columns from linear model:
orig <- with(meandata, s3d$xyz.convert(Ton, Tget, energy))
plane <- with(meandata, s3d$xyz.convert(Ton, Tget, fitted(lmodel)))
i.negpos <- 1+(resid(lmodel)>0)
segments(orig$x, orig$y, plane$x, plane$y, col=c("blue","red")[i.negpos],lty=(2:1)[i.negpos])
dev.off();
