rawdata<-read.table("rawF.dat", col.names=c("Ton", "Tget", "discomfort", "energy"))

# dataF<-read.table("dataF.dat", col.names=c("Ton", "Tget", "herring", "discomfort", "energy"))

dataF<-read.table("dataF.dat", col.names=c("Ton", "Tget", "discomfort", "energy"))


# raw <- data.frame(Ton=rawdata$Ton, Tget=rawdata$Tget, discomfort=rawdata$discomfort, energy=rawdata$energy)
raw <- data.frame(Ton=dataF$Ton, Tget=dataF$Tget, discomfort=dataF$discomfort, energy=dataF$energy)


### Troubleshooting the data:
# analyze the parameter space (to see if everything is fairly distributed):
with(raw, hist(Ton, breaks=c((min(Ton)-1):max(Ton))))
with(raw, hist(Tget, breaks=c((min(Tget)-1):max(Tget))))

# if frequency is not uniform, then check cumulative distribution over time:
Ton_vals<-data.frame(raw$Ton,count=ave(raw$Ton==raw$Ton, raw$Ton, FUN=cumsum))
Tget_vals<-data.frame(raw$Tget,count=ave(raw$Tget==raw$Tget, raw$Tget, FUN=cumsum))
# see if anything stands out from a line:
plot(Ton_vals[["count"]])
plot(Tget_vals[["count"]])


m_pareto_d<-read.table("means-pareto-by-d.dat", col.names=c("Ton", "Tget", "discomfort", "energy", "discomfort_err", "energy_err")) ; m_pareto_d
m_pareto_e<-read.table("means-pareto-by-e.dat", col.names=c("Ton", "Tget", "discomfort", "energy", "discomfort_err", "energy_err")) ; m_pareto_e


library("lattice")
small<-head(raw, 49*64)

trellis.device("postscript", color=FALSE)
postscript(file="scatter.eps", horizontal=F, paper="special", width=8, height=6)
xyplot(energy ~ discomfort, groups=(Ton*7+Tget), data=small, cex=0.5)
dev.off()

trellis.device("postscript", color=TRUE)
postscript(file="scatter-color.eps", horizontal=F, paper="special", width=8, height=6)
xyplot(energy ~ discomfort, groups=(Ton*7+Tget), data=small, cex=0.5)
dev.off()

trellis.device("svg", color=TRUE)
svg(file="scatter-color.svg", horizontal=F)
xyplot(energy ~ discomfort, groups=(Ton*7+Tget), data=small, cex=0.5)
dev.off()

